@@ -11,9 +11,11 @@ def get_thumbnail(url, geometry_string, **kwargs):
             url=url).valid().latest()
     except WebpageSnapshot.DoesNotExist:
         webpage_snapshot = WebpageSnapshot(url=url)
+        webpage_snapshot.save()
     return webpage_snapshot.get_thumbnail(geometry_string, **kwargs)
 
 
 def delete_image(sender, instance, **kwargs):
-    instance.image.delete(save=False)
+    if instance.image:
+        instance.image.delete(save=False)
 
